@@ -22,7 +22,6 @@ diversities <- calculate_diversities(
 test_that("internal checker doesn't fail us", {
   expect_is(Ps, "data.frame")
   expect_failure(expect_is(Ps, "data.table"))
-  
 })
 
 test_that("diversity_table() returns a pander object", {
@@ -31,7 +30,6 @@ test_that("diversity_table() returns a pander object", {
 })
 
 test_that("diversity_table() stops if object is not hagis.diversities object",
-          {
-            expect_error(diversities_table("y"),
+          {expect_error(diversities_table("y"),
                          regexp = "This is not a hagis.diversities object.")
           })
